@@ -4,14 +4,14 @@ import sys
 sys.path.insert(1,'..')
 sys.ps1 = None
 
-import Numeric
+import numpy
 from biggles.matlab import *
 
 def press_return():
 	print "[press return]"
 	sys.stdin.readline()
 
-x = Numeric.arrayrange(-10,10);
+x = numpy.arange(-10,10);
 y = x**2;
 e = y/4
 
