@@ -4,11 +4,11 @@ import sys
 sys.path.insert(1,'..')
 
 import biggles
-import Numeric, math
+import numpy, math
 
-x = Numeric.arange( 0, 3*math.pi, math.pi/30 )
-c = Numeric.cos(x)
-s = Numeric.sin(x)
+x = numpy.arange( 0, 3*math.pi, math.pi/30 )
+c = numpy.cos(x)
+s = numpy.sin(x)
 
 p = biggles.FramedPlot()
 p.title = "title"
