@@ -4,11 +4,11 @@ import sys
 sys.path.insert(1,'..')
 
 import biggles
-import math, Numeric 
+import math, numpy 
 
-x = Numeric.arange( 0, 2*math.pi, math.pi/20 )
-s = Numeric.sin(x)
-c = Numeric.cos(x)
+x = numpy.arange( 0, 2*math.pi, math.pi/20 )
+s = numpy.sin(x)
+c = numpy.cos(x)
 
 inset = biggles.FramedPlot()
 inset.title = "inset"
