@@ -4,10 +4,10 @@ import sys
 sys.path.insert(1,'..')
 
 import biggles
-import math, Numeric 
+import math, numpy 
 
-x = Numeric.arange( 0, 3*math.pi, math.pi/10 )
-y = Numeric.sin(x)
+x = numpy.arange( 0, 3*math.pi, math.pi/10 )
+y = numpy.sin(x)
 
 a = biggles.FramedArray( 2, 2, title='title' )
 a.aspect_ratio = 0.75
