@@ -1,7 +1,7 @@
 #
-# $Id: biggles.py,v 1.232 2003/05/12 22:14:41 mrnolta Exp $
+# $Id: biggles.py,v 1.235 2008/11/28 00:38:20 mrnolta Exp $
 #
-# Copyright (C) 2000-2001 Mike Nolta <mrnolta@users.sourceforge.net>
+# Copyright (C) 2000-2008 Mike Nolta <mrnolta@users.sourceforge.net>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
 #
 
 import copy, math, os, string
-import Numeric
+import numpy
 
 import config, _biggles
 from geometry import *
@@ -102,7 +102,7 @@ def _fontsize_relative( relsize, bbox, device ):
 class _PlotGeometry:
 
 	_logfunc = math.log10
-	_logfunc_vec = Numeric.log10
+	_logfunc_vec = numpy.log10
 
 	def __init__( self, src, dest, xlog=0, ylog=0 ):
 		self.src_bbox = src
@@ -127,8 +127,8 @@ class _PlotGeometry:
 		return self.aff( u, v )
 
 	def call_vec( self, x, y ):
-		u = Numeric.asarray( x )
-		v = Numeric.asarray( y )
+		u = numpy.asarray( x )
+		v = numpy.asarray( y )
 		if self.xlog: u = self._logfunc_vec(u)
 		if self.ylog: v = self._logfunc_vec(v)
 		return self.aff.call_vec( u, v )
@@ -506,7 +506,7 @@ class _DensityObject( _DeviceObject ):
 		return apply( BoundingBox, self.extent )
 
 	def draw( self, context ):
-		#from Numeric import rank
+		#from numpy import rank
 		#if rank(self.densgrid) == 3:
 		if len(self.densgrid.shape) == 3:
 			context.draw.color_density_plot( self.densgrid, self.extent )
@@ -650,6 +650,42 @@ class PlotLabel( _LabelComponent ):
 		t = apply( _TextObject, (pos, self.str), self.kw_style )
 		self.add( t )
 
+# _LabelsComponent ------------------------------------------------------------
+
+class _LabelsComponent( _PlotComponent ):
+
+	kw_rename = {
+		'face'		: 'fontface',
+		'size'		: 'fontsize',
+		'angle'		: 'textangle',
+		'halign'	: 'texthalign',
+		'valign'	: 'textvalign',
+	}
+
+	def __init__( self ):
+		_PlotComponent.__init__( self )
+		self.conf_setattr( "_LabelsComponent" )
+
+class Labels( _LabelsComponent ):
+
+	def __init__( self, x, y, labels, **kw ):
+		_LabelsComponent.__init__( self )
+		self.conf_setattr( "Labels" )
+		self.kw_init( kw )
+		self.x = x
+		self.y = y
+		self.labels = labels
+
+	def limits( self ):
+		p = min(self.x), min(self.y)
+		q = max(self.x), max(self.y)
+		return BoundingBox( p, q )
+
+	def make( self, context ):
+		x, y = context.geom.call_vec( self.x, self.y )
+		l = apply( _LabelsObject, (zip(x,y), self.labels), self.kw_style )
+		self.add( l )
+
 # _LineComponent --------------------------------------------------------------
 
 class _LineComponent( _PlotComponent ):
@@ -2151,6 +2187,9 @@ class FramedPlot( _PlotContainer ):
 		"ytitle"	: ("y1", "label"),
 	}
 
+	def __repr__( self ):
+		return "<biggles.FramedPlot instance>"
+
 	def __getattr__( self, name ):
 		if self._attr_map.has_key( name ):
 			xs = self._attr_map[ name ]
