@@ -1,5 +1,5 @@
 /*
- * $Id: libplot.c,v 1.9 2003/05/12 20:57:55 mrnolta Exp $ 
+ * $Id: libplot.c,v 1.12 2010/04/09 20:54:17 mrnolta Exp $ 
  *
  * Copyright (C) 2001 Mike Nolta <mrnolta@users.sourceforge.net>
  *
@@ -24,11 +24,7 @@
 #include <math.h>
 #include <plot.h>
 
-#ifdef NO_NUMERIC_INCDIR
-#include <arrayobject.h>
-#else
-#include <Numeric/arrayobject.h>
-#endif
+#include <numpy/arrayobject.h>
 
 typedef int bool_t;
 #define TRUE 1
@@ -186,7 +182,7 @@ static PyObject *
 new( PyObject *self, PyObject *args )
 {
 	PyObject *o, *odict, *ofile, *key, *value;
-	int pos;
+	Py_ssize_t pos;
 	char *type, *skey, *svalue;
 	FILE *outfile;
 	plPlotterParams *params;
